@@ -22,10 +22,12 @@ hook_version
 FORWARDED_ARGS=()
 MAN_ARGS=()
 BAT_ARGS=()
+OPT_EXPORT_ENV=false
 
 SHIFTOPT_SHORT_OPTIONS="SPLIT"
 while shiftopt; do
 	case "$OPT" in
+		--export-env) OPT_EXPORT_ENV=true ;;
 		--paging|--pager) shiftval; FORWARDED_ARGS+=("${OPT}=${OPT_VAL}");
 		                            BAT_ARGS+=("${OPT}=${OPT_VAL}") ;;
 		*)                          MAN_ARGS+=("$OPT") ;;
@@ -68,6 +70,14 @@ if [[ -n "${MANPAGER}" ]]; then BAT_PAGER="$MANPAGER"; fi
 export MANPAGER="env BATMAN_IS_BEING_MANPAGER=yes bash $(printf "%q " "$SELF" "${FORWARDED_ARGS[@]}")"
 export MANROFFOPT='-c'
 
+# If `--export-env`, print exports to use batman as the manpager directly.
+if "$OPT_EXPORT_ENV"; then
+	printf "export %s=%q\n" \
+		"MANPAGER" "$MANPAGER" \
+		"MANROFFOPT" "$MANROFFOPT"
+	exit 0
+fi
+
 # If no argument is provided and fzf is installed, use fzf to search for man pages.
 if [[ "${#MAN_ARGS[@]}" -eq 0 ]] && [[ -z "$BATMAN_LEVEL" ]] && command -v "$EXECUTABLE_FZF" &>/dev/null; then
 	export BATMAN_LEVEL=1
